@@ -1,5 +1,5 @@
 from .nouns import Nouns
-from .availability import domain_fully_available
+from .availability import domain_available_for_tlds
 
 
 class RandomNameGenerator:
@@ -12,16 +12,20 @@ class RandomNameGenerator:
 
     def generate(self, number=20):
         pre_propositions = []
-        while len(pre_propositions) != number:
+        while len(pre_propositions) < number:
             random_noun = self.nouns.generate()
             if (
                 len(random_noun) >= self.min_length
                 and len(random_noun) <= self.max_length
             ):
-                domains = domain_fully_available(
+                domains = domain_available_for_tlds(
                     random_noun.lower(), exclusive=self.exclusive, tlds=self.tlds
                 )
                 if domains:
-                    print(domains)
-                    pre_propositions.append(domains)
+                    print(
+                        random_noun.ljust(self.max_length + 1),
+                        "-->",
+                        ", ".join(domains),
+                    )
+                    pre_propositions.append({"name": random_noun, "domains": domains})
         return pre_propositions
